@@ -1,28 +1,27 @@
 package Dancer::RPCPlugin::ErrorResponse;
 use warnings;
 use strict;
-use Params::Validate ':all';
 
 use Exporter 'import';
 our @EXPORT = qw/error_response/;
 
+use Params::ValidationCompiler 'validation_for';
+
 sub error_response {
     __PACKAGE__->new(@_);
 }
 
 sub new {
     my $class = shift;
-    my $self = validate_with(
-        params => \@_,
-        spec   => {
+    my %self = validation_for(
+        params => {
             error_code    => {optional => 0},
             error_message => {optional => 0},
             error_data    => {optional => 1},
         },
-        allow_extra => 0,
-    );
+    )->(@_);
 
-    return bless($self, $class);
+    return bless(\%self, $class);
 }
 
 sub error_code    { $_[0]->{error_code} }
@@ -50,6 +49,20 @@ sub as_jsonrpc_error {
     };
 }
 
+sub as_restrpc_error {
+    my $self = shift;
+
+    my $data = $self->error_data;
+    return {
+        error => {
+            code => $self->error_code,
+            message => $self->error_message,
+            ($data ? (data => $data) : ()),
+        }
+    };
+}
+
+
 1;
 
 =head1 NAME
@@ -88,7 +101,7 @@ Factory function that retuns an instantiated L<Dancer::RPCPlugin::ErrorResponse>
 
 =head3 Responses
 
-An instance or an exception from L<Params::Validate>.
+An instance or an exception from L<Params::ValidationCompiler>.
 
 =head2 Dancer::RPCPlugin::ErrorResponse->new(%parameters)
 
@@ -106,7 +119,7 @@ An instance or an exception from L<Params::Validate>.
 
 =head3 Responses
 
-An instance or an exception from L<Params::Validate>.
+An instance or an exception from L<Params::ValidationCompiler>.
 
 =head2 $er->error_code
 
@@ -128,6 +141,10 @@ Returns a data-structure for the use in the C<error> field of a jsonrpc response
 
 Returns a data-structure for the use as a C<fault> response in XMLRPC.
 
+=head2 $er->as_restrpc_error
+
+Returns a data-structure like the C<error-field> in a JSONRPC2 error response.
+
 =head1 COPYRIGHT
 
 (c) MMXVII - Abe Timmerman <abetim@cpan.org>
